<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/spip?lang_cible=my
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// 0
	'0_URL' => 'http://listes.rezo.net/mailman/listinfo/spip-dev',
	'0_langue' => ' မြန်မာ[my]',
	'0_liste' => 'spip-en@rezo.net',
	'0_mainteneur' => 'George Kandalaft (george@diwanalarab.com)',

	// A
	'access_interface_graphique' => 'ရုပ်ပုံစာမျက်နှာသို့ ပြန်သွားပါ',
	'access_mode_texte' => 'ရိုးရိုးစာမျက်နှာကို ပြပါ',
	'admin_debug' => 'ပြန်ပြင်ပါ',
	'admin_modifier_article' => 'ဤစာစောင်ကို ပြန်ပြင်ပါ',
	'admin_modifier_auteur' => 'ဤစာရေးသူကို ပြန်ပြင်ရန်',
	'admin_modifier_breve' => 'ဤသတင်းကို ပြန်ပြင်ပါ',
	'admin_modifier_mot' => 'ဤစာစုကို ပြန်ပြင်ပါ',
	'admin_modifier_rubrique' => 'ဤအပိုင်းကို ပြန်ပြင်ပါ',
	'admin_recalculer' => 'ဤစာမျက်နှာကို ပြန်ဖွင့်ပါ',
	'afficher_trad' => 'ဘာသာပြန်ကို ပြပါ',
	'alerte_maj_impossible' => '<b>သတိပေးချက်!</b> MySQL မူကွဲ @version@သို့ မြင့်တင်ရန် အ​ဆင်မ​ပြေပါ၊ ခွင့်ပြုချက် ပြသနာကြောင့် ဖြစ်နိုင်ပါသည်။ သင့် ISPကိုဆက်သွယ်ပါ',
	'analyse_xml' => 'XML parsing',
	'antispam_champ_vide' => 'ဤနေရာကို ချန်လပ်ထားပေးပါ',
	'articles_recents' => 'အသစ်ဆုံး ဆောင်းပါးများ',
	'avis_archive_incorrect' => 'ဖိုင်တွဲသည် SPIP ဖိုင်အမျိုးအ​စား မဟုတ်ပါ',
	'avis_archive_invalide' => 'ဖိုင်တွဲမရှိပါ',
	'avis_attention' => ' * သတိပေးချက် * ',
	'avis_champ_incorrect_type_objet' => 'ဒီ @type@ အ​မျိုးအစားအတွက် နာမည်@name@ မရှိပါ',
	'avis_colonne_inexistante' => 'ကော်လံ @col@ မရှိပါ',
	'avis_erreur' => 'အမှား၊ အောက်ပါကို ကြည့်ရှုပါ',
	'avis_erreur_connexion' => 'ဆက်သွယ်မှု အမှား',
	'avis_erreur_cookie' => 'cookie ပြသနာ',
	'avis_erreur_fonction_contexte' => 'ပရိုဂရမ် အ​မှား၊ ဤလုပ်​ဆောင်ချက်ကို ထပ်မံမခေါ်သင့်ပါ',
	'avis_erreur_mysql' => 'MySQL အမှား',
	'avis_erreur_sauvegarde' => 'အရန်ထိန်းသိမ်းမှု အမှား (@type@ @id_objet@)!',
	'avis_erreur_visiteur' => 'ကိုယ်ပိုင်ကန့်သတ် နယ်​မြေသို့ ဝင်ရန်အ​ခက်အ​ခဲရှိသည်',

	// B
	'barre_a_accent_grave' => 'အစဉ်လိုက်ကို စီရန် A ထည့်ပါ',
	'barre_aide' => 'သင့်မြင်ကွင်းကို ပြုပြင်​အချောသတ်ရန် စာရိုက်စနစ်ကို အသုံးပြုပါ',
	'barre_e_accent_aigu' => 'အစဉ်လိုက်ကို စီရန် E ထည့်ပါ',
	'barre_eo' => 'oe-ligature ကိုထည့်ပါ',
	'barre_eo_maj' => 'EO-ligature ကိုထည့်ပါ',
	'barre_euro' => '€ ​အမှတ်ကို ထည့်သွင်းပါ',
	'barre_gras' => '{{bold type}} ထဲတွင်ထည့်ပါ',
	'barre_guillemets' => 'မျက်တောင် \\"ဖွင့်၊ ပိတ်\\" ကြားတွင်ထည့်ပါ',
	'barre_guillemets_simples' => 'မျက်တောင် ’ဖွင့်၊ ပိတ်’ ကြားတွင်ထည့်ပါ',
	'barre_intertitre' => '{{{subheading}}} သို့ပြန်ပြောင်းပါ',
	'barre_italic' => '{italics} စာလုံးစောင်းနှင့် ထည့်ပါ',
	'barre_lien' => '[hyperlink->http://...]သို့ပြောင်းပါ',
	'barre_lien_input' => 'သင့် hyperlink လိပ်စာကိုထည့်ပါ (နမူနာ၊ http://www.mysite.com ဒီဝက်ဘ်ဆိုက်ပေါ်ရှိ ဆောင်းပါး နံပါတ်ကို ထည့်သွင်းပါ)',
	'barre_note' => '[[Footnote]]သို့ပြန်သွားပါ',
	'barre_quote' => '<quote>စာစောင်ကို ကုဒ်လုပ်ပါ</quote>',
	'bouton_changer' => 'ပြုပြင်ရန်',
	'bouton_chercher' => 'ရှာဖွေရန်',
	'bouton_choisir' => 'ရွေးချယ်ရန်',
	'bouton_enregistrer' => 'သိမ်းဆည်းရန်',
	'bouton_radio_desactiver_messagerie_interne' => 'အတွင်းသတင်းစကား ပေးပို့ခြင်းတားမြစ်ရန်',
	'bouton_radio_envoi_annonces' => 'အယ်ဒီတာ့ ပြန်ကြားချက်များ ပေးပို့ရန်',
	'bouton_radio_non_envoi_annonces' => 'မည့်သည့်ပြန်ကြားချက်မျှ မပို့ရန်',
	'bouton_radio_non_envoi_liste_nouveautes' => 'နောက်ဆုံးရ သတင်းစာရင်း မပို့ရန်',
	'bouton_recharger_page' => 'ဤစာမျက်နှာကို ပြန်ဖွင့်ရန်',
	'bouton_telecharger' => 'ထည့်သွင်းရန်',
	'bouton_upload' => 'ထည့်သွင်းရန်', # MODIF
	'bouton_valider' => 'တင်သွင်းရန်',

	// C
	'cal_apresmidi' => 'နေ့လည်ပိုင်း (p.m.)',
	'cal_jour_entier' => 'တနေ့လုံး',
	'cal_matin' => 'မနက်ပိုင်း (a.m.)',
	'cal_par_jour' => 'နေ့တိုင်းပြ calendar',
	'cal_par_mois' => 'လတိုင်းပြ calendar',
	'cal_par_semaine' => 'အ​ပတ်တိုင်းပြ calendar',
	'choix_couleur_interface' => 'အရောင်',
	'choix_interface' => 'စာမျက်နှာ ပုံစံရွေးချယ်ရန်',
	'colonne' => 'ကော်လံ',
	'confirm_changer_statut' => 'အ​တည်ပြုချက် လိုအပ်သည်၊ ဤဆောင်းပါး၏ အနေအထားကို ပြုပြင်လိုပါသလား?',
	'correcte' => 'မှန်ကန်သည်',

	// D
	'date_aujourdhui' => 'ဒီနေ့',
	'date_avant_jc' => 'B.C.',
	'date_dans' => '@delai@ထဲမှာ',
	'date_de_mois_1' => '@j@ @nommois@',
	'date_de_mois_10' => '@j@ @nommois@',
	'date_de_mois_11' => '@j@ @nommois@',
	'date_de_mois_12' => '@j@ @nommois@',
	'date_de_mois_2' => '@j@ @nommois@',
	'date_de_mois_3' => '@j@ @nommois@',
	'date_de_mois_4' => '@j@ @nommois@',
	'date_de_mois_5' => '@j@ @nommois@',
	'date_de_mois_6' => '@j@ @nommois@',
	'date_de_mois_7' => '@j@ @nommois@',
	'date_de_mois_8' => '@j@ @nommois@',
	'date_de_mois_9' => '@j@ @nommois@',
	'date_demain' => 'မနက်ဖြန်',
	'date_fmt_heures_minutes' => '@h@:@m@',
	'date_fmt_jour_heure' => '@jour@ မှ @heure@',
	'date_fmt_jour_mois' => '@jourmois@',
	'date_fmt_jour_mois_annee' => '@jourmois@ @annee@',
	'date_fmt_mois_annee' => '@nommois@ @annee@',
	'date_fmt_nomjour_date' => '@nomjour@ @date@ မှာ',
	'date_heures' => 'အ​ချိန်နာရီ',
	'date_hier' => 'မနေ့က',
	'date_il_y_a' => '@delai@ လွန်​အချိန်မှာ',
	'date_jnum1' => '၁',
	'date_jnum10' => '၁၀',
	'date_jnum11' => '၁၁',
	'date_jnum12' => '၁၂',
	'date_jnum13' => '၁၃',
	'date_jnum14' => '၁၄',
	'date_jnum15' => '၁၅',
	'date_jnum16' => '၁၆',
	'date_jnum17' => '၁၇',
	'date_jnum18' => '၁၈',
	'date_jnum19' => '၁၉',
	'date_jnum2' => '၂',
	'date_jnum20' => '၂၀',
	'date_jnum21' => '၂၁',
	'date_jnum22' => '၂၂',
	'date_jnum23' => '၂၃',
	'date_jnum24' => '၂၄',
	'date_jnum25' => '၂၅',
	'date_jnum26' => '၂၆',
	'date_jnum27' => '၂၇',
	'date_jnum28' => '၂၈',
	'date_jnum29' => '၂၉',
	'date_jnum3' => '၃',
	'date_jnum30' => '၃၀',
	'date_jnum31' => '၃၁',
	'date_jnum4' => '၄',
	'date_jnum5' => '၅',
	'date_jnum6' => '၆',
	'date_jnum7' => '၇',
	'date_jnum8' => '၈',
	'date_jnum9' => '၉',
	'date_jour_1' => 'တနင်္ဂနွေ',
	'date_jour_1_abbr' => 'နွေ',
	'date_jour_1_initiale' => 'န',
	'date_jour_2' => '​တနင်္လာ',
	'date_jour_2_abbr' => 'လာ',
	'date_jour_2_initiale' => 'လ',
	'date_jour_3' => 'အင်္ဂါ',
	'date_jour_3_abbr' => 'ဂါ',
	'date_jour_3_initiale' => 'ဂ',
	'date_jour_4' => '​ဗုဒ္ဓဟူး',
	'date_jour_4_abbr' => 'ဟူး',
	'date_jour_4_initiale' => 'ဟ',
	'date_jour_5' => 'ကြာတပတေး',
	'date_jour_5_abbr' => 'ကြာ',
	'date_jour_5_initiale' => 'က',
	'date_jour_6' => 'သောကြာ',
	'date_jour_6_abbr' => 'သော',
	'date_jour_6_initiale' => 'သ',
	'date_jour_7' => 'စနေ',
	'date_jour_7_abbr' => 'နေ',
	'date_jour_7_initiale' => 'စ',
	'date_jours' => 'ရက်များ',
	'date_minutes' => 'မိနစ်များ',
	'date_mois' => 'လများ',
	'date_mois_1' => '	ျပာသုိ',
	'date_mois_10' => ' ျပာသုိ',
	'date_mois_11' => 'တန္ေဆာင္မုန္း',
	'date_mois_12' => 'တန္ေပါင္း',
	'date_mois_2' => 'တပုိတ႔ ဲြ',
	'date_mois_3' => 'နယုန္',
	'date_mois_4' => 'ဝါဆုိ',
	'date_mois_6' => ' ေတာ္သလင္း',
	'date_mois_7' => 'သီတင္းကြ်တ္',
	'date_mois_8' => 'တန္ေဆာင္မုန္း',
	'date_mois_9' => 'နတ္ေတာ္',
	'date_saison_1' => 'ဆောင်းရာသီ',
	'date_saison_2' => 'နွေဦးရာသီ',
	'date_saison_3' => 'နွေရာသီ',
	'date_saison_4' => 'မိုးရာသီ',
	'date_semaines' => 'အ​ပတ်များ',
	'dirs_commencer' => '​ထည့်သွင်းခြင်းကို တကယ်လုပ်ရန်',
	'dirs_preliminaire' => 'ရှေးဦးမှတ်ချက်၊ <b>လုပ်ပိုင်ခွင့်ကို ​အရင်ဦးဆုံး သတ်မှတ်ပါ</b>',
	'dirs_probleme_droits' => 'လုပ်ပိုင်ခွင့် ပြသနာရှိနေသည်',
	'dirs_repertoires_absents' => '<p><b>အောက်ပါ ဖိုင်တွဲများ မတွေ့ရှိပါ</b></p><ul>@bad_dirs@</ul><p>ဖိုင်တွဲနာမည် စာလုံးအကြီးအသေး ပြသနာကြောင့် ဖြစ်နိုင်သည်။ ပြန်လည် စမ်းစစ်ရန် လိုအပ်သည်</p><p>စမ်းစစ်လို့ အဆင်ပြေနိုင်ပါသည်',
	'dirs_repertoires_suivants' => '<p><b>အောက်ပါဖိုင်တွဲများ ထပ်မံရေးပိုင်ခွင့် ခွင့်ပြုချက်မရှိပါ </b></p><ul>@bad_dirs@</ul>
<p>သင့် FTP client ကိုသုံးပြီး ပြောင်းလဲနိုင်ပါသည်။ အသေးစိတ်သိရှိလိုပါက အ​ညွှန်းစာတမ်းကို ပြန်ကြည့်ပါ</p><p>အဲဒီလိုပြင်ပြီးရင်တော့ ​အဆင်ပြေမှာပါ',
	'double_occurrence' => '​အဖြစ်အပျက် နှစ်ခု', # MODIF

	// E
	'envoi_via_le_site' => 'ဝက်ဘ်ဆိုက်မှတဆင့် ပေးပို့ပါ',
	'erreur' => 'အမှားအယွင်း',
	'erreur_balise_non_fermee' => 'နောက်ဆုံး တေးမှတ်ချက် ပိတ်မထားပါ',
	'erreur_texte' => 'အမှား(များ)',

	// F
	'fichier_introuvable' => '@fichier@ဖိုင်မတွေ့ရပါ',
	'form_deja_inscrit' => 'သင်မှတ်ပုံတင်ထားပြီးပြီ',
	'form_email_non_valide' => 'သင့်အီးမေးလ် မှန်ကန်မှုမရှိပါ',
	'form_forum_access_refuse' => 'ဤဝက်ဘ်ဆိုက်ထဲသို့ ဝင်​ခွင့် သင့်မှာမရှိတော့ပါ',
	'form_forum_bonjour' => 'မင်္ဂလာပါ @nom@',
	'form_forum_email_deja_enregistre' => 'ဤအီးမေးလ်သည် မှတ်ပုံတင်ထားပြီးဖြစ်ပါတယ်၊ ပုံမှန်စကားဝှက်ကို အသုံးပြုနိုင်ပါသည်',
	'form_forum_identifiant_mail' => 'သင့်အမှတ်အသားသစ်ကို အီးမေးလ်မှတဆင့် ပို့ထားပြီးပြီ',
	'form_forum_identifiants' => 'ကိုယ်ပိုင် အမှတ်အသား',
	'form_forum_indiquer_nom_email' => 'သင့်နာမည်နှင့် အီးမေးလ်လိပ်စာကို ထည့်ပါ၊ များမကြာမီ ချိန်အတွင်း သင့်ကိုယ်ပိုင် အမှတ်အသားကို အီးမေးလ်မှတဆင့်ရောက်လာပါလိမ့်မည်',
	'form_forum_login' => 'ဝင်ရန်',
	'form_forum_message_auto' => '(ဤသတင်းစကားသည် အလိုအလျှောက် ဖြစ်သည်)',
	'form_forum_pass' => 'စကားဝှက်',
	'form_forum_probleme_mail' => 'မေးလ်ပြသနာ၊ ဒီစာကို ပို့မပေးနိုင်ပါ',
	'form_forum_voici1' => 'ဒီမှာ \\"@nom_site_spip@\\" (@adresse_site@) သင့်ရဲ့အမှတ်အသား',
	'form_forum_voici2' => 'ဆောင်းပါးများ တင်သွင်းရန် ဒီမှာသင့်ရဲ့ မှတ်ပုံတင် \\"@nom_site_spip@\\" (@adresse_login@)',
	'form_indiquer_email' => 'သင့်ရဲ့အီးမေးလ် လိပ်စာကိုထည့်ပါ',
	'form_indiquer_nom' => 'သင့်နာမည်ကိုထည့်ပါ',
	'form_indiquer_nom_site' => 'သင့်ဝက်ဘ်ဆိုက် နာမည်ကိုထည့်ပါ',
	'form_pet_deja_enregistre' => 'ဤဆိုက်သည် မှတ်ပုံတင်ထားပြီးသားဖြစ်သည်',
	'form_pet_signature_pasprise' => 'သင့်လက်မှတ်ကတော့ လျစ်လျှူရှုခြင်းခံရပါတယ်',
	'form_prop_confirmer_envoi' => 'ပို့ဆောင်မှုကို အတည်ပြုပါ',
	'form_prop_description' => 'အကျဉ်းချုံးဖော်ပြချက်/မှတ်ချက်',
	'form_prop_enregistre' => 'သင့်အဆိုပြုချက်ကို လက်ခံရရှိထားပါသည်၊ ဝက်ဘ်ဆိုက်ကြီးကြပ်သူမှ အတည်ပြုပြီးရင် အွန်လိုင်းမှာ ပေါ်လာပါလိမ့်မည်။',
	'form_prop_envoyer' => 'သတင်းစကားပေးပို့ရန်',
	'form_prop_indiquer_email' => 'အမှန်တကယ်ရှိသော အီးမေးလ်လိပ်စာကို ထည့်ပါ',
	'form_prop_indiquer_nom_site' => 'ဝက်ဘ်ဆိုက်နာမည်ကို ထည့်ပါ',
	'form_prop_indiquer_sujet' => 'အကြောင်းအရာကို ထည့်ပါ',
	'form_prop_message_envoye' => 'စာ​စောင်ပို့ပေးပြီ',
	'form_prop_non_enregistre' => 'သင့်အကြံပြုချက် သိမ်းဆည်းထားခြင်းမရှိသေးပါ',
	'form_prop_sujet' => 'အကြောင်းအရာ',
	'form_prop_url_site' => 'ဆိုက်လိပ်စာ', # MODIF
	'forum_non_inscrit' => 'သင်မှတ်ပုံတင်ထားခြင်း မရှိ (သို့) စကားဝှက် မှားယွင်းနေတာဖြစ်ပါလိမ့်မည်',
	'forum_par_auteur' => 'မှ @auteur@',
	'forum_titre_erreur' => 'မှားယွင်းမှု',

	// I
	'ical_texte_rss_articles' => 'ဆိုက်ဆောင်းပါးဖိုင်ရဲ့ လိပ်စာကတော့',
	'ical_texte_rss_articles2' => 'အခန်းကဏ္ဍတိုင်းရှိ​ ဆောင်းပါးများကိုလည်း ရယူနိုင်ပါသည်',
	'ical_texte_rss_breves' => 'သတင်းအမျိုးအစား ဖိုင်များပါဝင်​တာလည်းရှိတယ်။ အခန်းကဏ္ဍ နံပါတ်ကို ရွေးချယ်ခြင်းဖြင့် သတင်းအမျိုးအစား သက်သက်ကိုလည်းရနိုင်ပါသည်',
	'icone_a_suivre' => 'ထုတ်ဝေမှုနေရာ',
	'icone_admin_site' => 'ဆိုက် စီမံခန့်ခွဲခြင်း',
	'icone_agenda' => 'ပြက္ခဒိန်',
	'icone_aide_ligne' => 'အကူအညီရယူရန်',
	'icone_articles' => 'ဆောင်းပါများ',
	'icone_auteurs' => 'စာရေးသူ',
	'icone_brouteur' => 'အမြန်ကြည့်ရှုရန်',
	'icone_configuration_site' => 'စီမံတပ်ဆင်ရန်',
	'icone_configurer_site' => 'သင့်ဝက်ဘ်ဆိုက်ကို စီမံ​တပ်ဆင်ပါ',
	'icone_creer_nouvel_auteur' => 'စာရေးသူအသစ် ဖန်တီးရန်',
	'icone_creer_rubrique' => 'အခန်းကဏ္ဍအသစ် ဖန်တီးရန်',
	'icone_creer_sous_rubrique' => 'အခန်းကဏ္ဍခွဲ ဖန်တီးရန်',
	'icone_deconnecter' => 'ထွတ်ရန်',
	'icone_discussions' => 'ဆွေးနွေးရန်',
	'icone_doc_rubrique' => 'ပူးတွဲစာ တင်သွင်းရန်',
	'icone_ecrire_article' => 'ဆောင်းပါးအသစ် ရေးသားရန်',
	'icone_edition_site' => 'တည်းဖြတ်ရန်',
	'icone_gestion_langues' => 'ဘာသာစကား စီမံရန်',
	'icone_informations_personnelles' => 'ကိုယ်ရေးကိုတာ အချက်အလက်',
	'icone_interface_complet' => 'ပြီးပြည့်စုံသော စာမျက်နှာ',
	'icone_interface_simple' => 'ရိုးစင်း​သော စာမျက်နှာ',
	'icone_maintenance_site' => 'ဆိုက်ပြုပြင်စီမံရန်',
	'icone_messagerie_personnelle' => 'ကိုယ်ပိုင် စာစောင်ပေးပို့ရန်',
	'icone_repartition_debut' => 'ကနဦးအစမှ ထုတ်ဝေမှုကို ထုတ်ပြပါ',
	'icone_rubriques' => 'အခန်းကဏ္ဍများ',
	'icone_sauver_site' => 'သိုလောင်သိမ်းဆည်းရန်',
	'icone_site_entier' => 'ဆိုက်တစ်ခုလုံး',
	'icone_sites_references' => 'အညွှန်းဝက်ဘ်ဆိုက်များ',
	'icone_statistiques' => 'ဝက်ဘ်ဆိုက်နှင့် သက်ဆိုင်သော အခြေပြဇယား',
	'icone_suivi_activite' => 'ဝက်ဘ်ဆိုက်လုပ်ဆောင်မှု နောက်ဆက်တွဲ',
	'icone_suivi_actualite' => 'ဝက်ဘ်ဆိုက်နှင့်သက်ဆိုင်သော အခြေပြဇယား',
	'icone_suivi_pettions' => 'လျှောက်လဲမှုကို စီမံရန်',
	'icone_suivi_revisions' => 'ဆောင်ပါးများ ပြန်လည်ကြည့်ရှုရန်',
	'icone_supprimer_document' => 'ဤစာရွက်ကို ပယ်ဖျက်ရန်',
	'icone_supprimer_image' => 'ဤပုံကိုပယ်ဖျက်ရန်',
	'icone_tous_articles' => 'ဆောင်းပါးများအားလုံး',
	'icone_tous_auteur' => 'စာရေးသူများအားလုံး',
	'icone_visiter_site' => 'ဆိုက်ကိုသွားလည်ပါ', # MODIF
	'icone_voir_en_ligne' => 'အွန်လိုင်းတွင်ကြည့်ရှုရန်',
	'img_indisponible' => 'ပုံမရနိုင်ပါ',
	'impossible' => 'မဖြစ်နိုင်ပါ',
	'info_a_suivre' => 'စီစဉ်ထုတ်ပြန်မှုနေရာ»',
	'info_acces_interdit' => 'ဝင်ရောက်ခွင့် တားမြစ်ထားသည်',
	'info_acces_refuse' => 'ဝင်ခွင့်ငြင်းပယ်ခြင်းခံရသည်',
	'info_action' => 'လုပ်ဆောင်ချက် @action@',
	'info_administrer_rubriques' => 'ဤအခန်းကဏ္ဍနှင့် ကဏ္ဍခွဲများကို သင်စီမံနိုင်သည်',
	'info_adresse_non_indiquee' => 'စမ်းသပ်ရန် လိပ်စာကိုပေးထားခြင်းမရှိသေးပါ',
	'info_aide' => 'အကူအညီရယူရန်',
	'info_ajouter_mot' => 'ဤစကားစုကို ထည့်ပါ',
	'info_annonce' => 'ကြေငြာချက်',
	'info_annonces_generales' => 'အထွေထွေကြေငြာချက်များ',
	'info_article_propose' => 'ဆောင်းပါးများတင်သွင်းပြီး',
	'info_article_publie' => 'ဆောင်းပါးတင်သွင်းပြီး',
	'info_article_redaction' => 'ဆောင်းပါးရေးသားနေဆဲ',
	'info_article_refuse' => 'ဆောင်းပါးငြင်းပယ်ခြင်းခံရသည်',
	'info_article_supprime' => 'ဆောင်းပါးပယ်ဖျက်ပြီး',
	'info_articles' => 'ဆောင်းပါး',
	'info_articles_a_valider' => 'ဆောင်းပါးများကို ပြန်လည်အတည်ပြုရန်',
	'info_articles_proposes' => 'ဆောင်းပါးတင်သွင်းပြီး',
	'info_auteurs_nombre' => 'စာရေးသူ(များ)',
	'info_authentification_ftp' => 'စမ်းစစ်အတည်ပြုခြင်း(FTP မှ)',
	'info_breves_2' => 'သတင်း',
	'info_connexion_refusee' => 'ဆက်သွယ်ရန်ကြိုးစားမှု ငြင်းပယ်ခံရသည်',
	'info_contact_developpeur' => 'တီထွင်သူကိုဆက်သွယ်ပါ',
	'info_contenance' => 'ဆိုက်ထဲပါဝင်သည့် အရာများမှာ၊',
	'info_contribution' => 'ဖိုရမ်တွင် ထည့်ဝင်မှု', # MODIF
	'info_copyright' => '@spip@ သည်အခမဲ့ရနိုင်သော @lien_gpl@ ဆောက်ဝဲလ်ဖြစ်သည်',
	'info_copyright_doc' => 'ပိုမိုသိရှိရန် <a href="@spipnet@">http://www.spip.net/en</a> သို့သွားပါ', # MODIF
	'info_copyright_gpl' => 'အများဆိုင် GPL လိုင်စင်ဖြင့်ထုတ်ဝေသည့်',
	'info_cours_edition' => 'သင့်ဆောင်းပါးသည် ပြင်ဆင်နေဆဲဖြစ်တယ်',
	'info_creer_repertoire' => 'ဖိုင် သို့မဟုတ် ဖိုင်တွဲကိုဖန်တီးပါ',
	'info_creer_repertoire_2' => '<b>@repertoire@</b>ရဲ့အထဲမှာ၊ ပြီးတော့',
	'info_creer_vignette' => 'အလိုအလျှောက်ဖန်တီးသော နမူနာပုံ',
	'info_deplier' => 'ဖွင့်ချသည်',
	'info_descriptif_nombre' => 'ဖော်ပြချက်(များ)',
	'info_description' => 'ဖော်ပြချက်',
	'info_description_2' => 'ဖော်ပြချက်',
	'info_dimension' => 'အရွယ်အစား',
	'info_ecire_message_prive' => 'ကိုယ်ရေးကိုတာ သတင်းစကား',
	'info_email_invalide' => 'မရှိသေးသော အီးမေးလ်လိပ်စာ',
	'info_en_cours_validation' => 'သင့်ဆောင်းပါးများသည် ပြင်ဆင်နေဆဲဖြစ်သည်',
	'info_en_ligne' => 'အွန်လိုင်းတွင်ရှိနေတယ်',
	'info_envoyer_message_prive' => 'ကိုယ်ရေးကိုတာ အချက်အလက်များကို ဤစာရေးသူထံသို့ ပေးပို့ရန်',
	'info_erreur_requete' => 'ဆက်သွယ်မှု အမှားအယွင်း',
	'info_erreur_squelette2' => 'မဖြစ်နိုင်သော ပုံစံစာမျက်နှာ<b>@fichier@</b>...',
	'info_erreur_systeme' => 'စက်ပြသနာ (errno @errsys@)',
	'info_erreur_systeme2' => 'ဟတ်ဒေးစ် ပြည့်ပြီး သို့မဟုတ် သိုလှောင်မှု ပျက်ဆီးနေသည်<br />
<span style="color:red;">သိုလှောင်မှုကို ပြုပြင်ရန် <a href=\'@script@\'>ကိုနှိပ်ပါ</a>၊ သို့မဟုတ် သင့်ဝက်ဘ်ဆိုက် ဆိုင်ရာများကို ဆက်သွယ်ပါ။</span>',
	'info_fini' => 'လုပ်ပြီးသွားပြီ',
	'info_format_image' => 'ပုံစံဒီဇိုင်းစင်ရန်အတွက် ပုံရိပ် @gd_formats@',
	'info_format_non_defini' => 'မသိသေးသော ပုံစံ',
	'info_grand_ecran' => 'အကြီးချဲ့ကြည့်ရန်',
	'info_image_aide' => 'အကူအညီရယူပါ',
	'info_image_process_titre' => 'နမူနာပုံကို ဖန်တီးရန်နည်းလမ်း',
	'info_impossible_lire_page' => '<b>အမှားအယွင်း</b> ဒီစာမျက်နှာကို <tt><html>@test_proxy@</html></tt>  မှကျော်ဖတ်၍မရနိုင်ပါဘူး',
	'info_installation_systeme_publication' => 'ထုတ်ဝေမှုကို ထည့်သွင်းထားရန်',
	'info_installer_documents' => 'ဤ @upload@ ဖိုင်​တွဲထဲတွင်ရှိသော အရာများအားလုံးကို သင်ထည့်သွင်းနိုင်သည်',
	'info_installer_ftp' => 'စီမံခန့်ခွဲသူ​အနေနှင့် FTP မှ @upload@ ဖိုင်​တွဲထဲတွင် ထည့်ထားသော အရာများကို နောက်နောင်တွင်အသုံးပြုရန် ဤနေရာမှ ရွေးချယ်နိုင်သည်။',
	'info_installer_images' => 'ပုံရိပ်အမျိုးအစား JPEG, GIF နှင့် PNG များကို ထည့်သွင်းအသုံးပြုနိုင်သည်',
	'info_installer_images_dossier' => 'ဖိုင်တွဲ @upload@ တွင်ထည့်သွင်းထား​မည့် ပုံရိပ်များကို ဤနေရာမှရွေးချယ်ပါ',
	'info_interface_complete' => 'ပြည့်စုံသော စာမျက်နှာ',
	'info_interface_simple' => 'ရိုစင်းသော စာမျက်နှာ',
	'info_joindre_document_article' => 'သင့်ဆောင်းပါးနှင့် ပူးတွဲနိုင်သော အ​မျိုးအစားများ',
	'info_joindre_document_rubrique' => 'ဤအခန်းကဏ္ဍနှင့် တွဲဖက် ထည့်သွင်းနိုင်သော အမျိုးအစားများ',
	'info_joindre_documents_article' => 'သင့်ဆောင်းပါးနှင့် ပူးတွဲနိုင်သော အ​မျိုးအစားများ',
	'info_l_article' => 'ဆောင်းပါး',
	'info_la_breve' => 'သတင်း',
	'info_la_rubrique' => 'အ​ခန်းကဏ္ဍ',
	'info_langue_principale' => 'ဆိုက်အဓိက ဘာသာစကား',
	'info_largeur_vignette' => '@largeur_vignette@ × @hauteur_vignette@ pixels',
	'info_les_auteurs_1' => 'မှ @les_auteurs@',
	'info_logo_format_interdit' => 'logo အမျိုးအစား @formats@ ကိုသာခွင့်ပြုသည်',
	'info_logo_max_poids' => 'Logo များ၏ အရွယ်အစားဟာ @maxi@ အောက်ရှိရပါမယ် (ဒီဖိုင်ဟာ @actuel@ရှိပါတယ်)',
	'info_mail_fournisseur' => 'you@isp.com',
	'info_message_2' => 'သတင်းစာစောင်',
	'info_message_supprime' => 'စာစောင်ပယ်ဖျက်ပြီး',
	'info_mise_en_ligne' => 'အွန်လိုင်းထုတ်ဝေသည့်ရက်စွဲ',
	'info_modification_parametres_securite' => 'လုံခြုံရေးဆိုင်ရာ အချက်အလက်များ ပြင်ဆင်ရန်',
	'info_mois_courant' => 'လအတွင်း',
	'info_mot_cle_ajoute' => 'အောက်ပါစကားစုများကို ထည့်သွင်းထားသည်',
	'info_multi_herit' => 'ကနဦး ဘာသာစကား',
	'info_multi_langues_soulignees' => 'အောက်လိုင်းသားထားသော ဘာသာစကားများသည် ပြည့်စုံသော ဘာသာပြန်ဖြစ်သည်', # MODIF
	'info_multilinguisme' => 'တစ်ခုထက်ပိုသော ဘာသာစကားအတွက် စီမံရန်',
	'info_nom_non_utilisateurs_connectes' => 'ချိတ်ဆက်ထားသော စရင်းတွင် သင့်နာမည် မရှိဘူး',
	'info_nom_utilisateurs_connectes' => 'ချိတ်ဆက်ထားသော စရင်းတွင် သင့်နာမည်လည်း ပါရှိပါတယ်',
	'info_nombre_en_ligne' => 'အွန်လိုင်းမှာရှိနေတယ်',
	'info_non_resultat' => '\\"@cherche_mot@\\"အ​တွက် မတွေ့ရှိသေးပါ',
	'info_non_utilisation_messagerie' => 'ဤဝက်ဘ်ဆိုက် အတွင်းသတင်းစကား ပေးပို့ခြင်းကို အသုံးမပြုရသေးပါဘူး',
	'info_nouveau_message' => 'သင့်မှာစာစောင် အသစ်ရှိပါသည်',
	'info_nouveaux_messages' => 'သင့်မှာစာစောင် အသစ် @total_messages@ ရောက်နေပါသည်',
	'info_numero_abbreviation' => 'မဟုတ်ဘူး',
	'info_pense_bete' => 'မှတ်တမ်း',
	'info_petit_ecran' => 'ဖော်ပြမှုအသေး',
	'info_pixels' => 'pixels',
	'info_plusieurs_mots_trouves' => '\\"@cherche_mot@\\" အတွက် စကားစုအမြောက်အများ တွေ့ရှိပါသည်',
	'info_portfolio_automatique' => 'အလိုအလျှောက်ရွေးချယ်မှု',
	'info_premier_resultat' => '[@debut_limit@ သည် @total@၏ ပထမတွေ့ရှိချက်]',
	'info_premier_resultat_sur' => '[@debut_limit@သည် @total@၏ ပထမတွေ့ရှိချက်]',
	'info_propose_1' => '[@nom_site_spip@] တင်သွင်းပြီး @titre@',
	'info_propose_2' => 'ဆောင်ပါးတင်သွင်းပြီး
-----------------',
	'info_propose_3' => 'ဤဆောင်ပါး \\"@titre@\\"သည် ထုတ်​​ဝေဖို့ရန်အတွက် တင်သွင်းပြီးဖြစ်ပါသည်',
	'info_propose_4' => 'ပြန်လည်ကြည့်ရှု စစ်ဆေးရန်နှင့် သဘောထားအမြင် ပေးရန်ဖိတ်ခေါ်ထားပါသည်',
	'info_propose_5' => 'ဖိုရမ်ထဲတွင်ရှိသော လိပ်စာအတိုင်း ဆက်သွယ်ပါ',
	'info_publie_01' => 'ဤ \\"@titre@\\" ဆောင်းပါးကို @connect_nom@ မှ စစ်ဆေးအတည်ပြုထားပါသည်',
	'info_publie_1' => '[@nom_site_spip@] ထုတ်​​ဝေပြီး @titre@',
	'info_publie_2' => 'ဆောင်းပါးထုတ်​​ဝေပြီး
-----------------',
	'info_rechercher' => 'ရှာဖွေရန်',
	'info_rechercher_02' => 'ရှာဖွေရန်',
	'info_remplacer_vignette' => 'ပေးထားသော လိုဂိုဒီရိုင်းကို သင်နှစ်သက်သော ဒီရိုင်းနှင့်အစားထိုးပါ',
	'info_sans_titre_2' => 'ခေါင်းစဉ်မရှိ​သေးပါ',
	'info_selectionner_fichier' => 'ဖိုင်များကို @upload@မှရွေးချယ်ရရှိနိုင်ပါသည်',
	'info_selectionner_fichier_2' => 'ဖိုင်ရွေးချယ်ပါ',
	'info_supprimer_vignette' => 'ဒီရိုင်းဆင်မြန်းခြင်းကို ပယ်ဖျက်ရန်',
	'info_symbole_bleu' => 'အပြာရောင် သ​င်္ကေတသည် မှတ်ချက်ကိုဖော်ပြသည်။ ဥပမာ၊ ကိုယ်ရေးကိုတာ စာစောင် စသည်ဖြင့်',
	'info_symbole_jaune' => 'အဝါရောင် သ​င်္ကေတသည် စာတည်းအဖွဲ့သားအားလုံးသို့ ​ကြေငြာချက်များဖြစ်သည်။ စာတည်းအဖွဲ့သား အားလုံးမှ တည်းဖြတ်နိုင်ပြီး၊ ​ဤ​အဖွဲ့သား အားလုံးသို့ မြင်သာအောင်ပြနိုင်သည်။',
	'info_symbole_vert' => 'အစိမ်းရောင် သ​င်္ကေတသည် ဤဆိုက်သုံးစွဲသူအချင်းချင်း သတင်းစကားများ ဖလှယ်ခြင်းဖြစ်သည်။</b>',
	'info_telecharger_nouveau_logo' => 'logo အသစ် တင်သွင်းရန်',
	'info_telecharger_ordinateur' => 'သင့်ကွန်ပျူတာမှ တင်သွင်းပါ',
	'info_tous_resultats_enregistres' => '[ရှာဖွေတွေ့ရှိချက်များအားလုံး မှတ်တမ်းတင်ထားပါသည်]',
	'info_tout_afficher' => 'အကုန်လုံးကိုပြရန်',
	'info_travaux_texte' => 'ဤဆိုက်သည် ပြင်ဆင်ထားခြင်းမရှိသေးပါ၊ နောက်မပြန်လာလည်ပါအုံး',
	'info_travaux_titre' => 'ဆိုက်တည်ဆောက်နေဆဲပါ',
	'info_trop_resultat' => '\\"@cherche_mot@\\" ​အတွက် ရှာဖွေတွေ့ရှိမှုအလွန်များသည်၊ ပြန်ချုံ့ကြည့်ပါအုံး',
	'info_utilisation_messagerie_interne' => 'အ​တွင်းစာစောင်ပို့ခြင်းကို သင်အသုံးပြုနေသည်',
	'info_valider_lien' => 'ဤအဆက်အသွယ်ကို ပြန်လည်အတည်ပြုပါ',
	'info_verifier_image' => 'သင့်ပုံရိပ်များသည် ​ကောင်းမွန်စွာ ပြောင်းလဲခြင်းရှိ၊ မရှိ ကိုစမ်းစစ်ပါ',
	'info_vignette_defaut' => 'ကနဦးဒီဇိုင်း',
	'info_vignette_personnalisee' => 'ဒီဇိုင်းပြန်ဆင်ရန်',
	'info_visite' => 'အလည်လာသူ',
	'info_vos_rendez_vous' => 'အနာဂတ်ချိန်းဆိုချက်',
	'infos_vos_pense_bete' => 'သင့်မှတ်တမ်းများ', # MODIF

	// L
	'lien_afficher_icones_seuls' => 'ရုပ်ပုံသက်သက်ကိုပြပေးပါ',
	'lien_afficher_texte_icones' => 'စာသားကိုပြပေးပါ',
	'lien_afficher_texte_seul' => 'စာသားသက်သက်ကိုပြပေးပါ',
	'lien_liberer' => 'လွှင့်သည်',
	'lien_liberer_tous' => 'ဤဆောင်းပါးများကို အခမဲ့ရနိုင်ပါသည်', # MODIF
	'lien_nouvea_pense_bete' => 'မှတ်ချက်အသစ်',
	'lien_nouveau_message' => 'စာစောင်အသစ်',
	'lien_nouvelle_annonce' => 'ထုတ်ပြန်ကြေငြာချက်အသစ်',
	'lien_petitions' => 'လျှောက်လဲတောင်းဆိုချက်',
	'lien_popularite' => 'ထင်ပေါ်မှုရာခိုင်နှုန်း @popularite@%',
	'lien_racine_site' => 'မူလနေရာ',
	'lien_reessayer' => 'ပြန်ကြိုးစားကြည့်ပါအုံး',
	'lien_repondre_message' => 'ဤစာစောင်ကို စာပြန်ရန်',
	'lien_supprimer' => 'ပယ်ဖျက်ပါ',
	'lien_tout_afficher' => 'အကုန်လုံးပြပါ',
	'lien_visite_site' => 'ဤဆိုက်ကိုသွားပါ',
	'lien_visites' => '@visites@ လာလည်သွားသည်',
	'lien_voir_auteur' => 'ဒီစာရေးသူကိုစစ်ဆေးပါ',
	'ligne' => 'လိုင်း',
	'login_acces_prive' => 'ကိုယ်ပိုင်ကန့်သတ်နေရာကို သွားပါ',
	'login_autre_identifiant' => 'တခြား IDကိုသုံးပါ',
	'login_cookie_accepte' => 'သင့် browser မှ ဤဆိုက်ကို လက်ခံအောင်လုပ်​ပေးပါ',
	'login_cookie_oblige' => 'သင့်လုံခြုံရေးအ​တွက် ဒီ cookies ကိုလက်ခံပါ',
	'login_deconnexion_ok' => 'ပိတ်သွားပြီ',
	'login_erreur_pass' => 'စကားဝှတ်အမှား',
	'login_espace_prive' => 'ကိုပိုင်နေရာ',
	'login_identifiant_inconnu' => 'မှတ်ပုံတင် \\"@login@\\" ကို မသိရှိပါ',
	'login_login' => 'အထဲဝင်ပါ',
	'login_login2' => 'အထဲဝင်ပါ (ကိုယ့်ကိုယ်ကိုဘယ်သူဖြ​စ်ကြောင်ဖော်ပြပါ)', # MODIF
	'login_login_pass_incorrect' => '(မှားယွင်းသော နာမည်၊ စကားဝှက်)',
	'login_motpasseoublie' => 'စကားဝှက်မေ့နေတာလား?',
	'login_non_securise' => 'သတိပေးချက်၊ ဒီလုပ်ဆောင်မှုသည် လုံခြုံမှုမရှိပါ၊ သင့်စကားဝှက်ကို သူများပေးမသိစေချင်းဘူးဆိုရင် သင့် browser တွင် Javascript ကိုလက်ခံအောင်လုပ်ပါ ပြီးတော့',
	'login_nouvelle_tentative' => 'ကြိုးစားမှုအသစ်',
	'login_par_ici' => 'ဤနည်းလမ်းအားဖြင့် သင်မှတ်ပုံတင်ထားပြီးပြီ',
	'login_pass2' => 'စကားဝှက်',
	'login_preferez_refuser' => '<b>cookies ကိုမှတ်မထားဖို့ နှစ်သက်တယ်ဆိုရင်</b> ဆက်သွယ်နိုင်တဲ့ တခြားနည်းလမ်းလည်း ရှိပါတယ်၊ လုံခြုံမှုတော့မရှိဘူးပေါ့',
	'login_recharger' => 'ဒီစာမျက်နှာကို ပြန်လုပ်ကြည့်ပါအုံး',
	'login_rester_identifie' => 'ကျွန်တော့် IDကို ရက်အနည်းငယ်လောက် မှတ်ထားပေးပါအုံး',
	'login_retour_public' => 'အများဆိုင် စာမျက်နှာသို့ ပြန်သွားရန်',
	'login_retour_site' => 'အများဆိုင် စာမျက်နှာသို့ ပြန်သွားရန်',
	'login_retoursitepublic' => 'အများဆိုင် စာမျက်နှာသို့ ပြန်သွားရန်',
	'login_sinscrire' => 'မှတ်ပုံတင်ရန်',
	'login_test_navigateur' => 'စမ်းသပ်ရန်',
	'login_verifiez_navigateur' => '(သင့် browser မှ သင့်စကားဝှက်ကို မမှတ်မိပါ)',

	// M
	'masquer_trad' => 'ဘာသာပြန်ကို ဝှက်ထားရန်',
	'module_fichiers_langues' => 'ဘာသာစကားဆိုင်ရာဖိုင်များ',

	// N
	'navigateur_pas_redirige' => 'သင့် browser မှ ​ပြောင်းလွဲပေးခြင်းမရှိလျှင် ဤနေရာသို့နှိပ်ခြင်းဖြင့် လိုရာသို့သွားနိုင်ပါသည်',
	'numero' => 'နံပါတ်',

	// O
	'occurence' => 'ပုံစံ',
	'onglet_affacer_base' => 'သိုလောင်မှု ဖျက်ပစ်ပါရန်',
	'onglet_auteur' => 'စာရေးသူ',
	'onglet_contenu_site' => 'ဆိုက်ထဲပါဝင်သည့်အရာ',
	'onglet_evolution_visite_mod' => 'လာလည်သူအဆင့်',
	'onglet_fonctions_avances' => 'အဆင့်မြင့်လုပ်ဆောင်မှု',
	'onglet_informations_personnelles' => 'ကိုယ်ရေးအ​ချက်အလက်',
	'onglet_interactivite' => 'အတူတကွလုပ်ဆောင်မှု',
	'onglet_messagerie' => 'စာစောင်​ပေးပို့နေသည်',
	'onglet_repartition_rubrique' => 'အခန်းကဏ္ဍအလိုက် ဝေမျှခြင်း',
	'onglet_save_restaur_base' => 'သိုလောင်မှု သိမ်းဆည်းရန်၊ ထည့်သွင်းရန်',
	'onglet_vider_cache' => 'မှတ်ဉာဏ်ကို ရှင်းပြစ်ပါ',

	// P
	'pass_choix_pass' => 'စကားဝှက် အသစ်ကိုပြန်ရွေးပါ',
	'pass_erreur' => 'အမှားအယွင်း',
	'pass_erreur_acces_refuse' => '<b>အမှားအယွင်း</b> ဤဝက်ဘ်ဆိုက်ကို သင်ဝင်ရောက်ခွင့် မရှိတော့ပါ',
	'pass_erreur_code_inconnu' => '<b>အမှားအယွင်း</b> ဤကုဒ်နှင့် ဒီဝက်ဘ်ဆိုက်ကို လာလည်သူ မ​တွေ့ရှိပါ',
	'pass_erreur_non_enregistre' => '<b>အမှားအယွင်း</b> လိပ်စာ <tt>@email_oubli@</tt> မှတ်ပုံတင်ထားခြင်းမရှိပါ',
	'pass_erreur_non_valide' => '<b>အမှားအယွင်း</b> လိပ်စာ <tt>@email_oubli@</tt> မရှိပါ!',
	'pass_erreur_probleme_technique' => '<b>အမှားအယွင်း</b> နည်းပညာအ​ခက်အခဲကြောင့် ဒီအီးမေးလ်ကို ပို့၍မရပါ',
	'pass_espace_prive_bla' => 'ဤကိုယ်ပိုင် ကန့်သတ်နယ်မြေဟာ ဒီဆိုက်ထဲမှတ်ပုံတင်ပြီးရင် ဝင်ရောက်နိုင်မှာဖြစ်ပါတယ်၊ ဆောင်းပါးများ ပြန်လည်ကြည့်ရှုခြင်း၊ တင်သွင်းခြင်းများနှင့် ဖိုရမ်တွင်ပါဝင် ရေးသားခြင်းများကိုလည်း ပြုလုပ်နိုင်မှာဖြစ်ပါတယ်။',
	'pass_forum_bla' => 'မှတ်ပုံတင်ထားသူများအတွက် ကြိုတင်လက်ဦးထားသော ဖိုရမ်တွင်ပါဝင်ရန် သင်တောင်းဆိုထားပါသည်',
	'pass_indiquez_cidessous' => 'မှတ်ပုံတင်ရာမှာသုံးသော အီးမေးလ် လိပ်စာကို အောက်တွင်ထည့်ပါ၊ ဘယ်လိုဝင်ရောက်၍ ရမလဲဆိုတဲ့ရှင်းပြချက်တွေကို အီးမေးလ်မှတဆင့် ပို့ပေးပါမည်။',
	'pass_mail_passcookie' => '(ဤစာစောင်သည် အလိုအလျှောက်ပေးပို့​တာ ဖြစ်တယ်) သင့်ဝက်ဘ်ဆိုက်နှင့် ပြန်လည်ဆက်သွယ်မှုရရန် @nom_site_spip@ (@adresse_site@) အောက်ဖော်ပြပါ လိပ်စာသို့သွားပါ @sendcookie@ စကားဝှက်ပြန်ထည့်ပြီး နောက်တဖန်ထပ်လုပ်ကြည့်ပါအုံး',
	'pass_mot_oublie' => 'စကားဝှက်မေ့လျော့သွားပြီ',
	'pass_nouveau_enregistre' => 'သင့်စကားဝှက် အသစ်ပြန်လည် ထည့်သွင်းထားပြီးပြီ',
	'pass_nouveau_pass' => 'စကားဝှက်အသစ်',
	'pass_ok' => 'အိုကေတယ်',
	'pass_oubli_mot' => 'စကားဝှက်မေ့နေတယ်',
	'pass_quitter_fenetre' => 'ဤစာမျက်နှာကိုပိတ်ပါ',
	'pass_rappel_login' => 'နိုးဆော်ချက်၊ သင့်​အမှတ်အသားကတော့ \\"@login@\\"',
	'pass_recevoir_mail' => 'သင့်ဝက်ဘ်ဆိုက်ထဲကို ဘယ်လိုပြန်လည် ဝင်ရောက်လို့ရမလဲ ဆိုတာကို အီးမေးလ်ရောက်လာပါလိမ့်မယ်',
	'pass_retour_public' => 'အများဆိုင် ဝက်ဘ်ဆိုက်ကို ပြန်သွားရန်',
	'pass_rien_a_faire_ici' => 'ဒီမှာဘာမှ လုပ်စရာမရှိပါဘူး',
	'pass_vousinscrire' => 'ဆိုက်နှင့် မှတ်ပုံတင်ထားပါ',
	'precedent' => 'အ​နာက်သို့',
	'previsualisation' => 'ကြိုတင်ကြည့်ရှုရန်',
	'previsualiser' => 'ကြိုတင်ကြည့်ရှုရန် ပြပေးပါ',

	// S
	'spip_conforme_dtd' => 'SPIP စာမျက်နှာသည် DOCTYPE စနစ်နှင့်ကိုက်ညီမှု ရှိကြောင်းတွေ့ရှိရသည်',
	'squelette' => 'စာမျက်နှာပုံစံခွက်',
	'squelette_inclus_ligne' => 'စာမျက်နှာပုံစံခွက်ထဲပါဝင်သည့် လိုင်း',
	'squelette_ligne' => 'စာမျက်နှာပုံစံခွက်လိုင်း',
	'stats_visites_et_popularite' => '@visites@ ယေက်လာလည်သွားသည်၊ ​ထင်ပေါ်ကျော်ကြားမှု @popularite@',
	'suivant' => '​နောက်တစ်ခု',

	// T
	'taille_ko' => '@taille@ kb',
	'taille_mo' => '@taille@ Mb',
	'taille_octets' => '@taille@ bytes',
	'texte_actualite_site_1' => 'စာမျက်နှာများနှင့် ရင်းနှီးကျွမ်းဝင်မှုရှိပြီဆိုရင် « ပိုပြီးပြည့်စုံအောင် ပြုလုပ်ရန်',
	'texte_actualite_site_2' => 'ပြီးပြည့်စုံသော စာမျက်နှာ',
	'texte_actualite_site_3' => '» ပေါ်တွင်နှိပ်ပါ',
	'texte_creation_automatique_vignette' => '​အ​လိုအ​လျှာက် ကြည့်ရှု၍ရအောင် ဤစာမျက်နှာပေါ်တွင် ပြုလုပ်ထားသည်၊ ဒီဖောင်မှတဆင့် ထည့်သွင်းလျှင် ရုပ်ပုံ @gd_formats@ အချိုးအစား၏ အကြီးဆုံး​အရွယ်အစားမှာ @taille_preview@ pixels ဖြစ်သည်',
	'texte_documents_associes' => 'အောက်ပါ စာမျက်နှာများသည် ဆောင်းပါးများနှင့် ဆက်စပ်မှုရှိသည်၊ သို့သော် တိုက်ရိုက် ထည့်သွင်းခြင်းတော့မဟုတ်။ အ​များဆိုင်ဆိုက် ဒီရိုင်းအပေါ် မူတည်၍ ပူးတွဲစာ အဖြစ်ဖော်ပြပါမည်။',
	'texte_erreur_mise_niveau_base' => 'သိုလှောင်မှုကို တိုးချဲ့မြှင့်တင်မှု လုပ်ဆောင်နေစဉ် အမှားအယွင်းဖြစ်သည်၊ ပုံရိပ်<b>@fichier@</b>သည် (ဆောင်းပါး @id_article@)ကိုကျော်ဖြတ်နိုင်မှုမရှိပါ<p> ဒီပုံရိပ်ဟာ စာတွေထဲ ပေါ်နေသလား သေချာစွာမှတ်သားပြီး နောက်တဖန် ထပ်ကြိုးစားကြည့်ပါအုံး။',
	'texte_erreur_visiteur' => 'သင့်ကိုခွင့်ပြုမထားသော နေရာသို့ဝင်ရောက်ရန် သင်ကြိုးစားခဲ့တယ်',
	'texte_inc_auth_1' => 'သင့်ကိုသင်​ <b>@auth_login@</b>ဟုတ်၊ မဟုတ် ​အတည်ပြုပါ၊ ဒါပေမယ့်လို့ သင့်မှတ်ပုံတင်ဟာ သိုလောင်မှုထဲမှာ မရှိတော့ပါဘူး၊ နောက်ထပ်ကြိုးစားချင်ရင်တော့ဖြင့်', # MODIF
	'texte_inc_auth_2' => 'ပြန်လည်ဆက်သွယ်ပါ',
	'texte_inc_auth_3' => 'ရပ်လိုက်ပြီး လိုအပ်လျှင် သင့် browser ကိုပြန်ဖွင့်ပါ',
	'texte_inc_config' => 'ဒီစာမျက်နှာများပေါ်မှာ လုပ်ဆောင်ချပ်များ ပိုမိုရရှိအောင် ရွေးချယ်မှုတွေကို လိုအပ်သလို ပြောင်းကြည့်ပါ၊ သို့သော် SPIPဟာ ဘယ်လို အလုပ်လုပ်သလဲဆိုတာကို ကောင်းကောင်းမသိသေးဘူး ဆိုယင်တော့ သိပ်အားမပေးလိုပါဘူး၊ သင့်ဝက်ဘ်ဆိုက်ဆရာကြီးကို အကြောင်းကြားဖို့တော့ မမေ့နှင့်ပေါ့။',
	'texte_inc_meta_1' => 'ဖိုင်<code>@fichier@</code>ကိုရေးသားဖို့ ကြိုးစားနေစဉ်မှာ စက်တွင်အခက်အခဲ ကြုံတွေ့ရပါသည်၊ ဆိုက်နှင့်သက်ဆိုင်သော ဆရာကြီးအနေဖြင့် ထပ်မှန်ကြိုးစားလိုက်ပါ',
	'texte_inc_meta_2' => 'ရေးသားခွင့်များကို ပြန်လည်စမ်းစစ်ပါ',
	'texte_inc_meta_3' => '<code>@repertoire@</code>၏ဖိုင်တွဲ',
	'texte_statut_en_cours_redaction' => 'တည်းဖြတ်နေဆဲပါ',
	'texte_statut_poubelle' => 'အမိုက်ပုံးထဲမှာ',
	'texte_statut_propose_evaluation' => 'ပြန်လည်စမ်းစစ်ရန် တင်သွင်းပြီး',
	'texte_statut_publie' => 'အွန်လိုင်းတွင် ထုတ်​​ဝေပြီး',
	'texte_statut_refuse' => 'ငြင်းပယ်ထားသည်',
	'titre_ajouter_mot_cle' => 'စကားစုထည့်ပါအုံး',
	'titre_cadre_raccourcis' => '​မာတိကာ',
	'titre_changer_couleur_interface' => 'စာမျက်နှာ အရာင်ပြောင်းရန်',
	'titre_image_admin_article' => 'သင့်တွင်ဤစာစောင်ကို စီမံခွင့်ရှိသည်',
	'titre_image_administrateur' => 'စီမံခန့်ခွဲသူ',
	'titre_image_aide' => 'အကူအညီရယူရန်',
	'titre_image_auteur_supprime' => 'စာရေးသူကို ပယ်ဖျက်ပြီးဖြစ်သည်',
	'titre_image_redacteur' => 'ဝင်ခွင့်မရှိဘဲနှင့် တည်းဖြတ်နိုင်သူ',
	'titre_image_redacteur_02' => 'စာတည်း',
	'titre_image_visiteur' => 'လာလည်သူ',
	'titre_joindre_document' => 'ပူးတွဲစာ တင်သွင်းရန်',
	'titre_mots_cles' => 'စကားစု',
	'titre_probleme_technique' => 'သတိပေးချက်၊ ဤနေရာသို့ ဝင်ရောက်ခွင့်ကို ​တားမြစ်ထားပါသည်၊ နားလည်မှုအတွက် ကျေးဇူးတင်ပါသည်။',
	'titre_publier_document' => 'ဤအခန်းကဏ္ဍထဲမှ ဆောင်းပါးများကို ထုတ်ဝေပါ',
	'titre_statistiques' => 'ဆိုက်လာလည်မှုစရင်း',
	'titre_titre_document' => 'စာမျက်နှာခေါင်းစဉ်',
	'trad_reference' => '(အညွှန်းဆောင်းပါး)', # MODIF

	// Z
	'zbug_balise_b_aval' => ': B tag too late in loop',
	'zbug_boucle' => 'loop',
	'zbug_champ_hors_boucle' => 'Field @champ@ outside loop',
	'zbug_code' => 'ကုဒ်',
	'zbug_critere_inconnu' => 'အမည်မသိ စံညွှန်း @critere@', # MODIF
	'zbug_distant_interdit' => 'ပြင်ပ ​အချက်အလက် တားမြစ်ထားသည်', # MODIF
	'zbug_doublon_table_sans_index' => 'စာညွှန်းတွင်မပါဘဲနှင့် ဇယားတွင် နှစ်ခါပါဝင်သည်', # MODIF
	'zbug_erreur_boucle_double' => 'BOUCLE@id@ နှစ်ခါထပ်နေသော အဓိပ္ပါယ်ဖွင့်ဆိုချက်', # MODIF
	'zbug_erreur_boucle_fermant' => 'BOUCLE@id@: အပိတ်တေးမှတ်ချက် မရှိဖြစ်ခြင်း', # MODIF
	'zbug_erreur_compilation' => 'စုဆောင်းမှု အမှားအယွင်း',
	'zbug_erreur_execution_page' => 'စာမျက်နှာတွက်ချက်မှု အမှားအယွင်း', # MODIF
	'zbug_erreur_filtre' => 'အမှားအယွင်း၊ ဖော်ပြမထားသော စမ်းစစ်ချက် @filtre@', # MODIF
	'zbug_erreur_squelette' => 'စာမျက်နှာ ပုံစံခွက်ထဲမှ အမှားအယွင်းများ',
	'zbug_info_erreur_squelette' => 'ُဆိုက်ထဲအမှားအယွင်း',
	'zbug_inversion_ordre_inexistant' => 'မရှိဘူး​​​သော စာစဉ်မှု', # MODIF
	'zbug_parametres_inclus_incorrects' => 'ထပ်မံဖြည့်စွပ်ချက် အမှား', # MODIF
	'zbug_resultat' => 'ရှာဖွေမှု ရလဒ်',
	'zbug_serveur_indefini' => 'ဖော်ပြခြင်းမရှိသော SQL ဆာဗာ', # MODIF
	'zbug_table_inconnue' => '​အမည်မသိ SQL ဇယား \\"@table@\\"',
	'zxml_connus_attributs' => '​အမည်မသိ ​အရည်အသွေးများ',
	'zxml_de' => 'မှ',
	'zxml_inconnu_attribut' => '​အမည်မသိ ​အရည်အသွေး',
	'zxml_inconnu_balise' => '​အမည်မသိ တေးမှတ်ချက်',
	'zxml_inconnu_entite' => '​အမည်မသိ အရာ​ဝတ္ထု',
	'zxml_inconnu_id' => '​အမည်မသိ ID',
	'zxml_mais_de' => 'သို့သော် ဤ​အရာမှ',
	'zxml_non_conforme' => 'မူအရမှန်ကန်မှု မရှိပါ',
	'zxml_non_fils' => 'ဆက်ခံမှုခွဲ မဟုတ်ပါ',
	'zxml_nonvide_balise' => 'တေးမှတ်ချက် လစ်ဟာမှုမရှိပါ',
	'zxml_obligatoire_attribut' => 'လိုအပ်နေသော အပိုင်းအစ မရှိပါ',
	'zxml_succession_fils_incorrecte' => 'မှားယွင်းသော ဆက်ခံမှုခွဲ',
	'zxml_survoler' => 'မှန်ကန်​သည့်အရာကိုတွေ့ရှိရန် ကာဆာကို အ​ပေါ်တွင်တင်ပါ',
	'zxml_valeur_attribut' => 'အပိုင်းအစတန်ဖိုး',
	'zxml_vide_balise' => 'တေးမှတ်ချက် မရှိပါ',
	'zxml_vu' => 'တွေ့ရှိပြီးပြီ'
);

?>
